@@ -22,7 +22,7 @@ class OneHostDistributorMangerRequestChannel(DistributorMangerRequestChannelConf
     """This class represents the DistributorMangerRequestChannel for the case
     Distributor and DistributorManager run on one host, which means, both Distributor and
     DistributorManager only need to bind their socket to the address
-    tcp://localhost:port
+    tcp://127.0.0.1:port
     However, if Distributor and DistributorManager are on different hosts, then the binding
     address could be different for each side. For now, this class assuming both are on the same host
     
@@ -34,7 +34,7 @@ class OneHostDistributorMangerRequestChannel(DistributorMangerRequestChannelConf
         address_template = super().generate_channel_address()
         # Assuming the distributor manager is in the same host so
         return address_template.format(
-            host_address="localhost"
+            host_address="127.0.0.1"
         )
 
 class DistributorMangerUserScriptRequestChannelConfig(TcpChannelConfig):
